@@ -13,7 +13,8 @@ from django.template import TemplateSyntaxError
 from django.views.debug import ExceptionReporter
 
 from sentry import conf
-from sentry.helpers import construct_checksum, varmap, transform, get_installed_apps, urlread, force_unicode
+from sentry.helpers import construct_checksum, varmap, transform, get_installed_apps, urlread, force_unicode, \
+                           get_versions
 
 logger = logging.getLogger('sentry.errors')
 
@@ -24,6 +25,28 @@ class SentryClient(object):
         kwargs.setdefault('level', logging.ERROR)
         kwargs.setdefault('server_name', conf.NAME)
 
+        # save versions of all installed apps
+        if 'data' not in kwargs or '__sentry__' not in (kwargs['data'] or {}):
+            if kwargs.get('data') is None:
+                kwargs['data'] = {}
+            kwargs['data']['__sentry__'] = {}
+
+        versions = get_versions()
+        kwargs['data']['__sentry__']['versions'] = versions
+
+        if kwargs.get('view'):
+            # get list of modules from right to left
+            parts = kwargs['view'].split('.')
+            module_list = ['.'.join(parts[:idx]) for idx in xrange(1, len(parts)+1)][::-1]
+            version = None
+            for m in module_list:
+                if m in versions:
+                    version = versions[m]
+
+            # store our "best guess" for application version
+            if version:
+                kwargs['data']['__sentry__']['version'] = version
+
         if 'checksum' not in kwargs:
             checksum = construct_checksum(**kwargs)
         else:
